@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+__version__ = "0.8.2"
+
 from datacompy.core import *
-from datacompy._version import __version__
-from datacompy.sparkcompare import SparkCompare, NUMERIC_SPARK_TYPES
+from datacompy.sparkcompare import NUMERIC_SPARK_TYPES, SparkCompare
