@@ -119,6 +119,8 @@ class Compare:
         self.df2_name = df2_name
         self.abs_tol = abs_tol
         self.rel_tol = rel_tol
+        self.ignore_spaces = ignore_spaces
+        self.ignore_case = ignore_case
         self.df1_unq_rows = self.df2_unq_rows = self.intersect_rows = None
         self.column_stats = []
         self._compare(ignore_spaces, ignore_case)
@@ -485,10 +487,15 @@ class Compare:
             ]
         return to_return
 
-    def all_mismatch(self):
+    def all_mismatch(self, ignore_matching_cols=False):
         """All rows with any columns that have a mismatch. Returns all df1 and df2 versions of the columns and join
         columns.
 
+        Parameters
+        ----------
+        ignore_matching_cols : bool, optional
+            Whether showing the matching columns in the output or not. The default is False.
+
         Returns
         -------
         Pandas.DataFrame
@@ -498,13 +505,34 @@ class Compare:
         return_list = []
         for col in self.intersect_rows.columns:
             if col.endswith("_match"):
-                match_list.append(col)
-                return_list.extend([col[:-6] + "_df1", col[:-6] + "_df2"])
+                orig_col_name = col[:-6]
+
+                col_comparison = columns_equal(
+                    self.df1[orig_col_name],
+                    self.df2[orig_col_name],
+                    self.rel_tol,
+                    self.abs_tol,
+                    self.ignore_spaces,
+                    self.ignore_case,
+                )
+
+                if not ignore_matching_cols or (
+                    ignore_matching_cols and not col_comparison.all()
+                ):
+                    LOG.debug("Adding column {} to the result.".format(orig_col_name))
+                    match_list.append(col)
+                    return_list.extend([orig_col_name + "_df1", orig_col_name + "_df2"])
+                elif ignore_matching_cols:
+                    LOG.debug(
+                        "Column {} is equal in df1 and df2. It will not be added to the result.".format(
+                            orig_col_name
+                        )
+                    )
 
         mm_bool = self.intersect_rows[match_list].all(axis="columns")
         return self.intersect_rows[~mm_bool][self.join_columns + return_list]
 
-    def report(self, sample_count=10, column_count=10):
+    def report(self, sample_count=10, column_count=10, html_file=None):
         """Returns a string representation of a report.  The representation can
         then be printed or saved to a file.
 
@@ -516,6 +544,9 @@ class Compare:
         column_count : int, optional
             The number of columns to display in the sample records output.  Defaults to 10.
 
+        html_file : str, optional
+            HTML file name to save report output to. If ``None`` the file creation will be skipped.
+
         Returns
         -------
         str
@@ -648,6 +679,12 @@ class Compare:
             report += self.df2_unq_rows.sample(unq_count)[columns].to_string()
             report += "\n\n"
 
+        if html_file:
+            html_report = report.replace("\n", "<br>").replace(" ", "&nbsp;")
+            html_report = f"<pre>{html_report}</pre>"
+            with open(html_file, "w") as f:
+                f.write(html_report)
+
         return report
 
 
